@@ -41,11 +41,11 @@ class LocaleContext(object):
             except Exception, ex:
                 raise ValueError("locale")
 
-    def from_now(self, time, precision=1, fromUTC=False):
+    def from_now(self, time, precision=1, from_utc=False):
         if isinstance(time, datetime.datetime):
             value = time
         else:
-            value = (datetime.datetime.utcfromtimestamp if fromUTC else datetime.datetime.fromtimestamp)(float(time))
+            value = (datetime.datetime.utcfromtimestamp if from_utc else datetime.datetime.fromtimestamp)(float(time))
 
         now = datetime.datetime.now()
         ago = now > value
@@ -74,13 +74,17 @@ def set_locale(locale):
     _locale.set_locale(locale)
 
 
-def from_now(datetime_or_timestamp, precision=1, fromUTC=False):
-    return _locale.from_now(datetime_or_timestamp, precision=precision, fromUTC=fromUTC)
+def from_now(datetime_or_timestamp, precision=1, from_utc=False):
+    return _locale.from_now(datetime_or_timestamp, precision=precision, from_utc=from_utc)
 
 
 if "__main__" == __name__:
-    print LocaleContext("ru").from_now(1377069799)
-    print LocaleContext("en").from_now(1377069799)
-    print LocaleContext("ro").from_now(1377069799)
-    print from_now(1377069799)
+    import time
+
+    for language in ["en", "ru", "ro"]:
+        locale = LocaleContext(language)
+
+        now = int(time.time())
+        for i in xrange(now - 10000000, now + 10000000, 60):
+            print locale.from_now(i)
 
