@@ -3,7 +3,7 @@
 from . import *
 
 forms = {
-    SECOND: ("несколько секунд",),
+    SECOND: "несколько секунд",
     MINUTE: ("минуту", "минута", "минуты", "минут"),
     HOUR: ("час", "час", "часа", "часов"),
     DAY: ("день", "день", "дня", "дней"),
@@ -13,19 +13,23 @@ forms = {
 
 
 class Locale(BaseLocale):
-    def plural(self, n, forms):
+    @staticmethod
+    def plural(n, forms_array):
         if n % 10 == 1 and n % 100 != 11:
-            return forms[1]
+            return forms_array[1]
         elif 4 >= n % 10 >= 2 and (n % 100 < 10 or n % 100 >= 20):
-            return forms[2]
+            return forms_array[2]
         else:
-            return forms[3]
+            return forms_array[3]
 
     def relative(self, target, number):
-        if number == 1 or target == SECOND:
-            return forms[target][0]
+        if target == SECOND:
+            return forms[SECOND]
         else:
-            return "%s %s" % (number, self.plural(number, forms[target]))
+            if number == 1:
+                return forms[target][0]
+            else:
+                return "%s %s" % (number, self.plural(number, forms[target]))
 
     def past(self, time):
         return "%s назад" % time
